package com.tencent.qcloud.ilivedemo.creat.view;

import android.Manifest;
import android.app.Activity;
import android.content.Context;
import android.content.pm.PackageManager;
import android.os.Build;
import android.os.Bundle;
import android.support.v4.app.ActivityCompat;
import android.view.View;
import android.view.inputmethod.InputMethodManager;
import android.widget.TextView;

import com.tencent.ilivesdk.view.AVRootView;
import com.tencent.qcloud.ilivedemo.creat.R;
import com.tencent.qcloud.ilivedemo.creat.presenter.RoomHelper;
import com.tencent.qcloud.ilivedemo.creat.viewinterface.IRoomView;
import com.tencent.qcloud.ilivedemo.creat.presenter.LoginHelper;
import com.tencent.qcloud.ilivedemo.creat.utils.UIUtils;

import java.util.ArrayList;
import java.util.List;


public class CreateRoomActivity extends Activity implements IRoomView {
    RoomHelper helper;
    private TextView mRooidEditor;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        checkPermission();
        setContentView(R.layout.activity_master_room);
        initView();
    }

    /**
     * 初始化UI
     */
    private void initView() {
        mRooidEditor = findViewById(R.id.room_id);
        helper = new RoomHelper(this);
        // 获取渲染控件
        AVRootView avRootView = findViewById(R.id.av_root_view);
        // 设置渲染控件
        helper.setRootView(avRootView);
    }

    public void createRoom(View view) {
        /**
         * 登录验证，创建房间先需先登录
         * demo里有个简单的登录控件，可以参考使用
         */
        if (!LoginHelper.isLogin()) {
            UIUtils.toastLongMessage("您还未登录");
            return;
        }
        /**
         * 验证房间号，合法的房间号为整型数字1~10000000
         * 房间号本应由服务器分配，demo测试可以自行输入
         */
        int roomId = -1;
        try {
            roomId = Integer.parseInt(mRooidEditor.getText().toString());
        } catch (Exception e) {
        }
        if (roomId >= 1 && roomId <= 10000000)
            helper.createRoom(roomId);
        else
            UIUtils.toastLongMessage("请输正确的入房间号(1~10000000)");
    }


    @Override
    public void onEnterRoom() {
        findViewById(R.id.room_id_group).setVisibility(View.GONE);
        InputMethodManager imm = (InputMethodManager) getSystemService(Context.INPUT_METHOD_SERVICE);
        imm.hideSoftInputFromWindow(mRooidEditor.getWindowToken(), 0);
        UIUtils.toastShortMessage("创建房间成功");
    }

    @Override
    public void onEnterRoomFailed(String module, int errCode, String errMsg) {
        UIUtils.toastLongMessage("创建房间失败：" + errCode + "::::" + errMsg);
    }

    @Override
    public void onQuitRoomSuccess() {
        findViewById(R.id.room_id_group).setVisibility(View.VISIBLE);
        UIUtils.toastShortMessage("退出房间成功");
    }

    @Override
    public void onQuitRoomFailed(String module, int errCode, String errMsg) {
        UIUtils.toastLongMessage("退出房间失败：" + errCode + "::::" + errMsg);
    }

    @Override
    public void onRoomDisconnect(int errCode, String errMsg) {
        UIUtils.toastLongMessage("连接断开：" + errCode + "::::" + errMsg);
    }


    protected boolean checkPermission() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            List<String> permissions = new ArrayList<>();
            if (PackageManager.PERMISSION_GRANTED != ActivityCompat.checkSelfPermission(this, Manifest.permission.WRITE_EXTERNAL_STORAGE)) {
                permissions.add(Manifest.permission.WRITE_EXTERNAL_STORAGE);
            }
            if (PackageManager.PERMISSION_GRANTED != ActivityCompat.checkSelfPermission(this, Manifest.permission.CAMERA)) {
                permissions.add(Manifest.permission.CAMERA);
            }
            if (PackageManager.PERMISSION_GRANTED != ActivityCompat.checkSelfPermission(this, Manifest.permission.RECORD_AUDIO)) {
                permissions.add(Manifest.permission.RECORD_AUDIO);
            }
            if (PackageManager.PERMISSION_GRANTED != ActivityCompat.checkSelfPermission(this, Manifest.permission.READ_PHONE_STATE)) {
                permissions.add(Manifest.permission.READ_PHONE_STATE);
            }
            if (PackageManager.PERMISSION_GRANTED != ActivityCompat.checkSelfPermission(this, Manifest.permission.READ_EXTERNAL_STORAGE)) {
                permissions.add(Manifest.permission.READ_EXTERNAL_STORAGE);
            }
            if (permissions.size() != 0) {
                ActivityCompat.requestPermissions(this,
                        (String[]) permissions.toArray(new String[0]),
                        100);
                return false;
            }
        }

        return true;
    }

    // 处理Activity事件
    public void onPause() {
        super.onPause();
        helper.onPause();
    }

    // 处理Activity事件
    public void onResume() {
        super.onResume();
        helper.onResume();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        helper.quitRoom();
    }
}
